@@ -31,7 +31,7 @@ SYSVLEVELS="2 3 4 5"
 PREVDIR=`pwd`
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+anyconnect-linux-3.1.03103-k9-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+anyconnect-linux-64-3.1.03103-k9-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco AnyConnect Secure Mobility Client"
 
 echo "Installing ${CLIENTNAME}..."
